@@ -1,20 +1,23 @@
 package Pod::Weaver::Plugin::Bencher::Scenario;
 
 our $DATE = '2016-03-15'; # DATE
-our $VERSION = '0.13'; # VERSION
+our $VERSION = '0.14'; # VERSION
 
 use 5.010001;
 use Moose;
 with 'Pod::Weaver::Role::AddTextToSection';
 with 'Pod::Weaver::Role::Section';
 
+has include_module => (is=>'rw');
+has exclude_module => (is=>'rw');
 has bench => (is=>'rw', default=>sub{1});
 has sample_bench => (is=>'rw');
 
-sub mvp_multivalue_args { qw(sample_bench) }
+sub mvp_multivalue_args { qw(sample_bench include_module exclude_module) }
 
 use Bencher::Backend;
 use Data::Dmp;
+use Perinci::Sub::Normalize qw(normalize_function_metadata);
 use Perinci::Sub::ConvertArgs::Argv qw(convert_args_to_argv);
 use String::ShellQuote;
 
@@ -125,7 +128,8 @@ sub _process_module {
                 my $res = eval $_;
                 $self->log_fatal(["Invalid sample_bench[$i] specification: %s", $@]) if $@;
 
-                my $cres = convert_args_to_argv(args => $res->{args}, meta => $Bencher::Backend::SPEC{bencher});
+                my $meta = normalize_function_metadata($Bencher::Backend::SPEC{bencher});
+                my $cres = convert_args_to_argv(args => $res->{args}, meta => $meta);
                 $self->log_fatal(["Invalid sample_bench[$i] specification: invalid args: %s - %s", $cres->[0], $cres->[1]])
                     unless $cres->[0] == 200;
                 my $cmd = "C<< bencher -m $scenario_name ".join(" ", map {shell_quote($_)} @{$cres->[2]})." >>";
@@ -312,6 +316,12 @@ sub weave_section {
     if ($filename =~ m!^lib/(Bencher/Scenario/.+)\.pm$!) {
         $package = $1;
         $package =~ s!/!::!g;
+        if ($self->include_module && @{ $self->include_module }) {
+            return unless grep {"Bencher::Scenario::$_" eq $package} @{ $self->include_module };
+        }
+        if ($self->exclude_module && @{ $self->exclude_module }) {
+            return if grep {"Bencher::Scenario::$_" eq $package} @{ $self->exclude_module };
+        }
         $self->_process_module($document, $input, $package);
     }
 }
@@ -331,13 +341,14 @@ Pod::Weaver::Plugin::Bencher::Scenario - Plugin to use when building Bencher::Sc
 
 =head1 VERSION
 
-This document describes version 0.13 of Pod::Weaver::Plugin::Bencher::Scenario (from Perl distribution Pod-Weaver-Plugin-Bencher-Scenario), released on 2016-03-15.
+This document describes version 0.14 of Pod::Weaver::Plugin::Bencher::Scenario (from Perl distribution Pod-Weaver-Plugin-Bencher-Scenario), released on 2016-03-15.
 
 =head1 SYNOPSIS
 
 In your F<weaver.ini>:
 
  [-Bencher::Scenario]
+ ;exclude_module=Foo
 
 =head1 DESCRIPTION
 
@@ -365,7 +376,19 @@ run and shown.
 
 =head1 OPTIONS
 
-=head2 sample_bench => hash
+=head2 include_module+ => str
+
+Filter only certain scenario modules. Can be specified multiple times.
+
+=head2 exclude_module+ => str
+
+Exclude certain scenario modules. Can be specified multiple times.
+
+=head2 sample_bench+ => hash
+
+Add a sample benchmark. Value is a hash which can contain these keys: C<title>
+(specify title for the benchmark), C<args> (hash arguments for bencher()). Can
+be specified multiple times.
 
 =head2 bench => bool (default: 1)
 
